IF OBJECT_ID('[DashboardFeeds]') IS NOT NULL DROP VIEW [DashboardFeeds]
GO

CREATE VIEW [DashboardFeeds]
AS
	SELECT [Feed_Id],
           [Feed_Name],
           [FeedType_Name],
           [Package_Download_Count] = COALESCE((SELECT SUM([Download_Count])
		                                 FROM [NuGetPackages]
										 WITH (READUNCOMMITTED)
										WHERE [Feed_Id] = F.[Feed_Id]), 0)
								    + COALESCE((SELECT SUM([Download_Count])
		                                 FROM [NuGetPackageVersionsV2] NPV
										 WITH (READUNCOMMITTED)
										      INNER JOIN [NuGetPackagesV2] NP
											        WITH (READUNCOMMITTED)
											          ON NP.[NuGetPackageV2_Id] = NPV.[NuGetPackageV2_Id]
										WHERE [Feed_Id] = F.[Feed_Id]), 0),
           [Package_Count] = (SELECT COUNT(*)
		                        FROM [NuGetPackages]
							    WITH (READUNCOMMITTED)
							   WHERE [Feed_Id] = F.[Feed_Id])
						   + (SELECT COUNT(*)
                                FROM [NuGetPackagesV2]
								WITH (READUNCOMMITTED)
							   WHERE [Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = COALESCE((SELECT SUM([Package_Size])
		                    FROM [NuGetPackages]
							WITH (READUNCOMMITTED)
						   WHERE [Feed_Id] = F.[Feed_Id]), 0)
					   + COALESCE((SELECT SUM([Package_Size])
		                    FROM [NuGetPackageVersionsV2] NPV
							WITH (READUNCOMMITTED)
							     INNER JOIN [NuGetPackagesV2] NP
								       WITH (READUNCOMMITTED)
								         ON NP.[NuGetPackageV2_Id] = NPV.[NuGetPackageV2_Id]
						   WHERE [Feed_Id] = F.[Feed_Id]), 0),
		   [Cache_Size] = COALESCE((SELECT SUM([Package_Size])
		                    FROM [NuGetPackages]
							WITH (READUNCOMMITTED)
						   WHERE [Feed_Id] = F.[Feed_Id]
						     AND [Cached_Indicator] = 'Y'), 0)
						+ COALESCE((SELECT SUM([Package_Size])
		                    FROM [NuGetPackageVersionsV2] NPV
							WITH (READUNCOMMITTED)
							     INNER JOIN [NuGetPackagesV2] NP
								       WITH (READUNCOMMITTED)
								         ON NP.[NuGetPackageV2_Id] = NPV.[NuGetPackageV2_Id]
						   WHERE [Feed_Id] = F.[Feed_Id]
						     AND [Cached_Indicator] = 'Y'), 0),
           F.[Active_Indicator]
      FROM [Feeds] F
	 WHERE F.[FeedType_Name] IN ('NuGet', 'Chocolatey', 'Deployment', 'PowerShell')

	UNION ALL

	SELECT [Feed_Id],
           [Feed_Name],
           [FeedType_Name],
           [Package_Download_Count] = COALESCE((SELECT SUM(NPV.[Download_Count])
		                                 FROM [NpmPackageVersions] NPV
										 WITH (READUNCOMMITTED)
										      INNER JOIN [NpmPackages] NP
										              ON NP.[Package_Id] = NPV.[Package_Id]
										WHERE [Feed_Id] = F.[Feed_Id]), 0),
           [Package_Count] = (SELECT COUNT(*)
		                        FROM [NpmPackages]
								WITH (READUNCOMMITTED)
							   WHERE [Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = COALESCE((SELECT SUM(COALESCE([Package_Size], 0))
		                    FROM [NpmPackageVersions] NPV
							WITH (READUNCOMMITTED)
							     INNER JOIN [NpmPackages] NP
								         ON NP.[Package_Id] = NPV.[Package_Id]
						   WHERE [Feed_Id] = F.[Feed_Id]), 0),
		   [Cache_Size] = COALESCE((SELECT SUM(COALESCE([Package_Size], 0))
		                    FROM [NpmPackageVersions] NPV
							WITH (READUNCOMMITTED)
							     INNER JOIN [NpmPackages] NP
								         ON NP.[Package_Id] = NPV.[Package_Id]
						   WHERE [Feed_Id] = F.[Feed_Id]
						     AND [Cached_Indicator] = 'Y'), 0),
           F.[Active_Indicator]
      FROM [Feeds] F
	 WHERE F.[FeedType_Name] = 'npm'

	UNION ALL

	SELECT [Feed_Id],
           [Feed_Name],
           [FeedType_Name],
           [Package_Download_Count] = COALESCE((SELECT SUM([Hit_Count])
		                                 FROM [BowerPackages]
										 WITH (READUNCOMMITTED)
										WHERE [Feed_Id] = F.[Feed_Id]), 0),
           [Package_Count] = (SELECT COUNT(*)
		                        FROM [BowerPackages]
								WITH (READUNCOMMITTED)
							   WHERE [Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = CAST(0 AS BIGINT),
		   [Cache_Size] = CAST(0 AS BIGINT),
           F.[Active_Indicator]
      FROM [Feeds] F
	 WHERE F.[FeedType_Name] = 'Bower'

	UNION ALL

	SELECT [Feed_Id],
	       [Feed_Name],
		   [FeedType_Name],
		   [Package_Download_Count] = COALESCE((SELECT SUM(MAF.[Download_Count])
		                                 FROM [MavenArtifactFiles] MAF
										      WITH (READUNCOMMITTED)
										      INNER JOIN [MavenArtifacts] MA
											        WITH (READUNCOMMITTED)
											          ON MA.[MavenArtifact_Id] = MAF.[MavenArtifact_Id]
										WHERE MA.[Feed_Id] = F.[Feed_Id]), 0),
		   [Package_Count] = (SELECT COUNT(*)
		                        FROM [MavenArtifacts]
							    WITH (READUNCOMMITTED)
							   WHERE [Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = COALESCE((SELECT SUM([File_Size])
		                    FROM [MavenArtifactFiles] MAF
							WITH (READUNCOMMITTED)
							     INNER JOIN [MavenArtifacts] MA
								         ON MA.[MavenArtifact_Id] = MAF.[MavenArtifact_Id]
						   WHERE [Feed_Id] = F.[Feed_Id]), 0),
		   [Cache_Size] = COALESCE((SELECT SUM([File_Size])
		                    FROM [MavenArtifactFiles] MAF
							WITH (READUNCOMMITTED)
							     INNER JOIN [MavenArtifacts] MA
								         ON MA.[MavenArtifact_Id] = MAF.[MavenArtifact_Id]
						   WHERE [Feed_Id] = F.[Feed_Id]
						     AND MAF.[Cached_Indicator] = 'Y'), 0),
           F.[Active_Indicator]
	 FROM [Feeds] F
	WHERE F.[FeedType_Name] = 'Maven'

	UNION ALL

	SELECT [Feed_Id],
	       [Feed_Name],
		   [FeedType_Name],
		   [Package_Download_Count] = COALESCE((SELECT SUM(PGP.[Download_Count])
		                                 FROM [ProGetPackages] PGP
										      WITH (READUNCOMMITTED)
										WHERE PGP.[Feed_Id] = F.[Feed_Id]), 0),
		   [Package_Count] = (SELECT COUNT(*)
		                        FROM [ProGetPackages]
							    WITH (READUNCOMMITTED)
							   WHERE [Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = COALESCE((SELECT SUM([Package_Size])
		                    FROM [ProGetPackageVersions] PGPV
							WITH (READUNCOMMITTED)
							     INNER JOIN [ProGetPackages] PGP
								         ON PGP.[ProGetPackage_Id] = PGPV.[ProGetPackage_Id]
						   WHERE [Feed_Id] = F.[Feed_Id]), 0),
		   [Cache_Size] = COALESCE((SELECT SUM([Package_Size])
		                    FROM [ProGetPackageVersions] PGPV
							WITH (READUNCOMMITTED)
							     INNER JOIN [ProGetPackages] PGP
								         ON PGP.[ProGetPackage_Id] = PGPV.[ProGetPackage_Id]
						   WHERE [Feed_Id] = F.[Feed_Id]
						     AND PGPV.[Cached_Indicator] = 'Y'), 0),
           F.[Active_Indicator]
	 FROM [Feeds] F
	WHERE F.[FeedType_Name] IN ('ProGet', 'Romp')

	UNION ALL

	SELECT [Feed_Id],
	       [Feed_Name],
		   [FeedType_Name],
		   [Package_Download_Count] = 0,
		   [Package_Count] = (SELECT COUNT(*)
		                        FROM [DockerImages]
							    WITH (READUNCOMMITTED)
							   WHERE [Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = COALESCE((SELECT SUM([Blob_Size])
		                    FROM [DockerBlobs]
							WITH (READUNCOMMITTED)
						   WHERE [Feed_Id] = F.[Feed_Id]), 0),
		   [Cache_Size] = 0,
           F.[Active_Indicator]
	 FROM [Feeds] F
	WHERE F.[FeedType_Name] = 'Docker'

	UNION ALL

	SELECT [Feed_Id],
	       [Feed_Name],
		   [FeedType_Name],
		   [Package_Download_Count] = COALESCE((SELECT SUM(RGV.[Download_Count])
		                                 FROM [RubyGemVersions] RGV
										      INNER JOIN [RubyGems] RG
											          ON RG.[Gem_Id] = RGV.[Gem_Id]
									    WHERE RG.[Feed_Id] = F.[Feed_Id]), 0),
		   [Package_Count] = (SELECT COUNT(*)
		                        FROM [RubyGems]
							   WHERE [Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = COALESCE((SELECT SUM(RGV.[Gem_Size])
		                    FROM [RubyGemVersions] RGV
							     INNER JOIN [RubyGems] RG
							             ON RG.[Gem_Id] = RGV.[Gem_Id]
						   WHERE RG.[Feed_Id] = F.[Feed_Id]
						     AND RGV.[Cached_Indicator] = 'N'), 0),
		   [Cache_Size] = COALESCE((SELECT SUM(RGV.[Gem_Size])
		                    FROM [RubyGemVersions] RGV
							     INNER JOIN [RubyGems] RG
							             ON RG.[Gem_Id] = RGV.[Gem_Id]
						   WHERE RG.[Feed_Id] = F.[Feed_Id]
						     AND RGV.[Cached_Indicator] = 'Y'), 0),
		   F.[Active_Indicator]
	  FROM [Feeds] F
	 WHERE F.[FeedType_Name] = 'RubyGems'

	UNION ALL

	SELECT [Feed_Id],
	       [Feed_Name],
		   [FeedType_Name],
		   [Package_Download_Count] = COALESCE((SELECT SUM(VP.[Download_Count])
		                                 FROM [VsixPackages] VP
									    WHERE VP.[Feed_Id] = F.[Feed_Id]), 0),
		   [Package_Count] = (SELECT COUNT(*)
		                        FROM [VsixPackages_Latest] VP
							   WHERE VP.[Feed_Id] = F.[Feed_Id]),
		   [Feed_Size] = COALESCE((SELECT SUM(VP.[Package_Size])
		                    FROM [VsixPackages] VP
						   WHERE VP.[Feed_Id] = F.[Feed_Id]
						     AND VP.[Cached_Indicator] = 'N'), 0),
		   [Cache_Size] = COALESCE((SELECT SUM(VP.[Package_Size])
		                    FROM [VsixPackages] VP
						   WHERE VP.[Feed_Id] = F.[Feed_Id]
						     AND VP.[Cached_Indicator] = 'Y'), 0),
		   F.[Active_Indicator]
	  FROM [Feeds] F
	 WHERE F.[FeedType_Name] = 'VSIX'

GO