EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'NpmFeeds_SetTagVersion',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Sets the version which a package tag points to.'
GO

IF OBJECT_ID('[NpmFeeds_SetTagVersion]') IS NOT NULL DROP PROCEDURE [NpmFeeds_SetTagVersion]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [NpmFeeds_SetTagVersion]
(
	@Feed_Id INT,
	@Package_Name NVARCHAR(200),
	@Scope_Name VARCHAR(200),
	@Tag_Name NVARCHAR(200),
	@Tag_Version VARCHAR(200)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

		DECLARE @Package_Id INT
		SET @Package_Id = (SELECT [Package_Id] FROM [NpmPackages] WHERE [Feed_Id] = @Feed_Id AND [Scope_Name] = @Scope_Name AND [Package_Name] = @Package_Name)

		IF @Package_Id IS NULL
			RAISERROR('Package was not found.', 16, 1)

		IF NULLIF(@Tag_Version, '') IS NULL
		BEGIN

			DELETE [NpmPackageTags]
			 WHERE [Package_Id] = @Package_Id
			   AND [Tag_Name] = @Tag_Name

		END
		ELSE IF EXISTS(SELECT * FROM [NpmPackageTags] WHERE [Package_Id] = @Package_Id AND [Tag_Name] = @Tag_Name)
		BEGIN

			UPDATE [NpmPackageTags]
			   SET [Tag_Version] = @Tag_Version
			 WHERE [Package_Id] = @Package_Id
			   AND [Tag_Name] = @Tag_Name

		END
		ELSE
		BEGIN

			INSERT INTO [NpmPackageTags]
			(
				[Package_Id],
				[Tag_Name],
				[Tag_Version]
			)
			VALUES
			(
				@Package_Id,
				@Tag_Name,
				@Tag_Version
			)

		END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [NpmFeeds_SetTagVersion] TO [ProGetUser_Role]
GO