EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Users_CreateGroup',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new user group.'
GO

IF OBJECT_ID('[Users_CreateGroup]') IS NOT NULL DROP PROCEDURE [Users_CreateGroup]
GO

CREATE PROCEDURE [Users_CreateGroup]
(
	@Group_Name NVARCHAR(50)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT *
				FROM [Users]
			   WHERE [User_Name] = @Group_Name)
		RAISERROR('Cannot create group "%s"; there is a user of the same name.', 16, 1)

	INSERT INTO [Groups]
	(
		[Group_Name]
	)
	VALUES
	(
		@Group_Name
	)

	EXEC [Events_RaiseEvent] 'USRNWG', NULL, 'Group_Name', @Group_Name

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Users_CreateGroup] TO [ProGetUser_Role]
GO
