EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Variables_CreateOrUpdateVariable',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Variable_Id',
    /* Description_Text        */ 'Creates a new variable, or updates an existing variable with the specified ID or matching scope.'
GO

IF OBJECT_ID('[Variables_CreateOrUpdateVariable]') IS NOT NULL DROP PROCEDURE [Variables_CreateOrUpdateVariable]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Variables_CreateOrUpdateVariable]
(
	@Variable_Name VARCHAR(50),
	@ValueType_Code CHAR(1),
	@Variable_Value VARBINARY(MAX),
    @Feed_Id INT = NULL,
    @Sensitive_Indicator YNINDICATOR = NULL,
    @EvaluateVariables_Indicator YNINDICATOR = NULL,
	@Variable_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

    DECLARE @Existing_Variable_Id INT

    SELECT @Existing_Variable_Id = [Variable_Id] 
      FROM [Variables]
     WHERE ([Variable_Id] = @Variable_Id) 
        OR  
        (   [Variable_Name] = @Variable_Name
            AND ([Feed_Id] = @Feed_Id OR ([Feed_Id] IS NULL AND @Feed_Id IS NULL))
        )

	IF @Existing_Variable_Id IS NOT NULL
	BEGIN

		UPDATE [Variables]
		   SET [Variable_Name] = @Variable_Name,
		       [ValueType_Code] = @ValueType_Code,
		       [Variable_Value] = @Variable_Value,
		       [Feed_Id] = @Feed_Id,
               [Sensitive_Indicator] = @Sensitive_Indicator,
               [EvaluateVariables_Indicator] = @EvaluateVariables_Indicator
		 WHERE [Variable_Id] = @Existing_Variable_Id

         SET @Variable_Id = @Existing_Variable_Id

	END
	ELSE
	BEGIN

		INSERT INTO [Variables]
		(
			[Feed_Id],
			[Variable_Name],
			[ValueType_Code],
			[Variable_Value],
            [Sensitive_Indicator],
            [EvaluateVariables_Indicator]
		)
		VALUES
		(
			@Feed_Id,
			@Variable_Name,
			@ValueType_Code,
			@Variable_Value,
            @Sensitive_Indicator,
            @EvaluateVariables_Indicator
		)

        SET @Variable_Id = SCOPE_IDENTITY()

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Variables_CreateOrUpdateVariable] TO [ProGetUser_Role]
